# Pytest Rest Api

PyTest расширение для тестирования API веб приложений.

Версия 0.0.1 служит бронью имени на pypi.org

<!-- ## Quick start

Подключение расширения:

```python
# conftest.py
pytest_plugins = [
    ...
    'pytest_rest_api'
    ...
]
```

Настройка подключения:

```python
# conftest.py
# TODO: После формирования интерфейса
```

Написание тестов:

```python
# conftest.py
# TODO: После формирования интерфейса
```

## Функциональность

### Кастомный клиент запросов к серверу

```python
# test_request.py

def test_request(client):
    # TODO: После формирования интерфейса

### Измерение времени запросов к серверу

Клиент для запросов сохраняет время выполнения запросов к серверу. -->
